@@ -7,13 +7,13 @@ SAMPLE_BEGIN(TextArea)
 auto container = Wt::cpp14::make_unique<Wt::WContainerWidget>();
 
 Wt::WTextArea *ta =
-    container->addWidget(Wt::cpp14::make_unique<Wt::WTextArea>());
+    container->addNew<Wt::WTextArea>();
 ta->setColumns(80);
 ta->setRows(5);
 ta->setText("Change this text... \n"
             "and click outside the text area to get a changed event.");
 
-Wt::WText *out = container->addWidget(Wt::cpp14::make_unique<Wt::WText>("<p></p>"));
+Wt::WText *out = container->addNew<Wt::WText>("<p></p>");
 out->addStyleClass("help-block");
 
 ta->changed().connect([=] {
